@@ -1,9 +1,9 @@
 import requests
 import time
-import logging
 from yyweaknet.stf import STFServer
+from logger import get_logger
 
-logger = logging.getLogger()
+logger = get_logger(__name__)
 
 
 class WeakNetworkConfig(object):
